@@ -20,13 +20,14 @@
 */
 
 /* global Windows, WinJS, MSApp */
+/* eslint prefer-regex-literals: 0 */
 
-var File = require('./File');
-var FileError = require('./FileError');
-var Flags = require('./Flags');
-var FileSystem = require('./FileSystem');
-var LocalFileSystem = require('./LocalFileSystem');
-var utils = require('cordova/utils');
+const File = require('./File');
+const FileError = require('./FileError');
+const Flags = require('./Flags');
+const FileSystem = require('./FileSystem');
+const LocalFileSystem = require('./LocalFileSystem');
+const utils = require('cordova/utils');
 
 function Entry (isFile, isDirectory, name, fullPath, filesystemName, nativeURL) {
     this.isFile = !!isFile;
@@ -37,26 +38,26 @@ function Entry (isFile, isDirectory, name, fullPath, filesystemName, nativeURL)
     this.nativeURL = nativeURL || null;
 }
 
-var FileEntry = function (name, fullPath, filesystemName, nativeURL) {
+const FileEntry = function (name, fullPath, filesystemName, nativeURL) {
     FileEntry.__super__.constructor.apply(this, [true, false, name, fullPath, filesystemName, nativeURL]);
 };
 
 utils.extend(FileEntry, Entry);
 
-var DirectoryEntry = function (name, fullPath, filesystemName, nativeURL) {
+const DirectoryEntry = function (name, fullPath, filesystemName, nativeURL) {
     DirectoryEntry.__super__.constructor.call(this, false, true, name, fullPath, filesystemName, nativeURL);
 };
 
 utils.extend(DirectoryEntry, Entry);
 
-var getFolderFromPathAsync = Windows.Storage.StorageFolder.getFolderFromPathAsync;
-var getFileFromPathAsync = Windows.Storage.StorageFile.getFileFromPathAsync;
+const getFolderFromPathAsync = Windows.Storage.StorageFolder.getFolderFromPathAsync;
+const getFileFromPathAsync = Windows.Storage.StorageFile.getFileFromPathAsync;
 
 function writeBytesAsync (storageFile, data, position) {
     return storageFile.openAsync(Windows.Storage.FileAccessMode.readWrite)
         .then(function (output) {
             output.seek(position);
-            var dataWriter = new Windows.Storage.Streams.DataWriter(output);
+            const dataWriter = new Windows.Storage.Streams.DataWriter(output);
             dataWriter.writeBytes(data);
             return dataWriter.storeAsync().then(function (size) {
                 output.size = position + size;
@@ -72,7 +73,7 @@ function writeTextAsync (storageFile, data, position) {
     return storageFile.openAsync(Windows.Storage.FileAccessMode.readWrite)
         .then(function (output) {
             output.seek(position);
-            var dataWriter = new Windows.Storage.Streams.DataWriter(output);
+            const dataWriter = new Windows.Storage.Streams.DataWriter(output);
             dataWriter.writeString(data);
             return dataWriter.storeAsync().then(function (size) {
                 output.size = position + size;
@@ -88,8 +89,8 @@ function writeBlobAsync (storageFile, data, position) {
     return storageFile.openAsync(Windows.Storage.FileAccessMode.readWrite)
         .then(function (output) {
             output.seek(position);
-            var dataSize = data.size;
-            var input = (data.detachStream || data.msDetachStream).call(data);
+            const dataSize = data.size;
+            const input = (data.detachStream || data.msDetachStream).call(data);
 
             // Copy the stream from the blob to the File stream
             return Windows.Storage.Streams.RandomAccessStream.copyAsync(input, output)
@@ -111,29 +112,29 @@ function writeArrayBufferAsync (storageFile, data, position) {
 
 function cordovaPathToNative (path) {
     // turn / into \\
-    var cleanPath = path.replace(/\//g, '\\');
+    let cleanPath = path.replace(/\//g, '\\');
     // turn  \\ into \
     cleanPath = cleanPath.replace(/\\+/g, '\\');
     return cleanPath;
 }
 
 function nativePathToCordova (path) {
-    var cleanPath = path.replace(/\\/g, '/');
+    const cleanPath = path.replace(/\\/g, '/');
     return cleanPath;
 }
 
-var driveRE = new RegExp('^[/]*([A-Z]:)');
-var invalidNameRE = /[\\?*|"<>:]/;
+const driveRE = new RegExp('^[/]*([A-Z]:)');
+const invalidNameRE = /[\\?*|"<>:]/;
 function validName (name) {
     return !invalidNameRE.test(name.replace(driveRE, ''));
 }
 
 function sanitize (path) {
-    var slashesRE = new RegExp('/{2,}', 'g');
-    var components = path.replace(slashesRE, '/').split(/\/+/);
+    const slashesRE = new RegExp('/{2,}', 'g');
+    const components = path.replace(slashesRE, '/').split(/\/+/);
     // Remove double dots, use old school array iteration instead of RegExp
     // since it is impossible to debug them
-    for (var index = 0; index < components.length; ++index) {
+    for (let index = 0; index < components.length; ++index) {
         if (components[index] === '..') {
             components.splice(index, 1);
             if (index > 0) {
@@ -148,7 +149,7 @@ function sanitize (path) {
     return components.join('/');
 }
 
-var WinFS = function (name, root) {
+const WinFS = function (name, root) {
     this.winpath = root.winpath;
     if (this.winpath && !/\/$/.test(this.winpath)) {
         this.winpath += '/';
@@ -156,8 +157,8 @@ var WinFS = function (name, root) {
     this.makeNativeURL = function (path) {
         // CB-11848: This RE supposed to match all leading slashes in sanitized path.
         // Removing leading slash to avoid duplicating because this.root.nativeURL already has trailing slash
-        var regLeadingSlashes = /^\/*/;
-        var sanitizedPath = sanitize(path.replace(':', '%3A')).replace(regLeadingSlashes, '');
+        const regLeadingSlashes = /^\/*/;
+        const sanitizedPath = sanitize(path.replace(':', '%3A')).replace(regLeadingSlashes, '');
         return FileSystem.encodeURIPath(this.root.nativeURL + sanitizedPath);
     };
     root.fullPath = '/';
@@ -168,11 +169,11 @@ var WinFS = function (name, root) {
 utils.extend(WinFS, FileSystem);
 
 WinFS.prototype.__format__ = function (fullPath) {
-    var path = sanitize('/' + this.name + (fullPath[0] === '/' ? '' : '/') + FileSystem.encodeURIPath(fullPath));
+    const path = sanitize('/' + this.name + (fullPath[0] === '/' ? '' : '/') + FileSystem.encodeURIPath(fullPath));
     return 'cdvfile://localhost' + path;
 };
 
-var windowsPaths = {
+const windowsPaths = {
     dataDirectory: 'ms-appdata:///local/',
     cacheDirectory: 'ms-appdata:///temp/',
     tempDirectory: 'ms-appdata:///temp/',
@@ -181,7 +182,7 @@ var windowsPaths = {
     applicationStorageDirectory: 'ms-appx:///'
 };
 
-var AllFileSystems;
+let AllFileSystems;
 
 function getAllFS () {
     if (!AllFileSystems) {
@@ -224,20 +225,20 @@ require('./fileSystems').getFs = function (name, callback) {
 };
 
 function getFilesystemFromPath (path) {
-    var res;
-    var allfs = getAllFS();
+    let res;
+    const allfs = getAllFS();
     Object.keys(allfs).some(function (fsn) {
-        var fs = allfs[fsn];
+        const fs = allfs[fsn];
         if (path.indexOf(fs.winpath) === 0) { res = fs; }
         return res;
     });
     return res;
 }
 
-var msapplhRE = new RegExp('^ms-appdata://localhost/');
+const msapplhRE = new RegExp('^ms-appdata://localhost/');
 function pathFromURL (url) {
     url = url.replace(msapplhRE, 'ms-appdata:///');
-    var path = decodeURIComponent(url);
+    let path = decodeURIComponent(url);
     // support for file name with parameters
     if (/\?/g.test(path)) {
         path = String(path).split('?')[0];
@@ -248,9 +249,10 @@ function pathFromURL (url) {
         }
     }
 
+    // eslint-disable-next-line
     ['file://', 'ms-appdata:///', 'ms-appx://', 'cdvfile://localhost/'].every(function (p) {
         if (path.indexOf(p) !== 0) { return true; }
-        var thirdSlash = path.indexOf('/', p.length);
+        const thirdSlash = path.indexOf('/', p.length);
         if (thirdSlash < 0) {
             path = '';
         } else {
@@ -263,11 +265,11 @@ function pathFromURL (url) {
 
 function getFilesystemFromURL (url) {
     url = url.replace(msapplhRE, 'ms-appdata:///');
-    var res;
+    let res;
     if (url.indexOf('file:/') === 0) { res = getFilesystemFromPath(pathFromURL(url)); } else {
-        var allfs = getAllFS();
+        const allfs = getAllFS();
         Object.keys(allfs).every(function (fsn) {
-            var fs = allfs[fsn];
+            const fs = allfs[fsn];
             if (url.indexOf(fs.root.nativeURL) === 0 ||
                 url.indexOf('cdvfile://localhost/' + fs.name + '/') === 0) {
                 res = fs;
@@ -280,12 +282,12 @@ function getFilesystemFromURL (url) {
 }
 
 function getFsPathForWinPath (fs, wpath) {
-    var path = nativePathToCordova(wpath);
+    const path = nativePathToCordova(wpath);
     if (path.indexOf(fs.winpath) !== 0) { return null; }
     return path.replace(fs.winpath, '/');
 }
 
-var WinError = {
+const WinError = {
     invalidArgument: -2147024809,
     fileNotFound: -2147024894,
     accessDenied: -2147024891
@@ -296,7 +298,7 @@ function openPath (path, ops) {
     return new WinJS.Promise(function (complete, failed) {
         getFileFromPathAsync(path).done(
             function (file) {
-                complete({ file: file });
+                complete({ file });
             },
             function (err) {
                 if (err.number !== WinError.fileNotFound && err.number !== WinError.invalidArgument) { failed(FileError.NOT_READABLE_ERR); }
@@ -343,15 +345,15 @@ function copyFolder (src, dst, name) {
                     complete();
                     return;
                 }
-                var todo = the.files.length;
-                var copyfolders = function () {
+                let todo = the.files.length;
+                const copyfolders = function () {
                     if (!(todo--)) {
                         complete();
                         return;
                     }
                     copyFolder(the.folders[todo], dst).done(function () { copyfolders(); }, failed);
                 };
-                var copyfiles = function () {
+                const copyfiles = function () {
                     if (!(todo--)) {
                         todo = the.folders.length;
                         copyfolders();
@@ -379,15 +381,15 @@ function moveFolder (src, dst, name) {
                     complete();
                     return;
                 }
-                var todo = the.files.length;
-                var movefolders = function () {
+                let todo = the.files.length;
+                const movefolders = function () {
                     if (!(todo--)) {
                         src.deleteAsync().done(complete, failed);
                         return;
                     }
                     moveFolder(the.folders[todo], the.fld).done(movefolders, failed);
                 };
-                var movefiles = function () {
+                const movefiles = function () {
                     if (!(todo--)) {
                         todo = the.folders.length;
                         movefolders();
@@ -403,23 +405,23 @@ function moveFolder (src, dst, name) {
 }
 
 function transport (success, fail, args, ops) { // ["fullPath","parent", "newName"]
-    var src = args[0];
-    var parent = args[1];
-    var name = args[2];
+    const src = args[0];
+    const parent = args[1];
+    const name = args[2];
 
-    var srcFS = getFilesystemFromURL(src);
-    var dstFS = getFilesystemFromURL(parent);
-    var srcPath = pathFromURL(src);
-    var dstPath = pathFromURL(parent);
+    const srcFS = getFilesystemFromURL(src);
+    const dstFS = getFilesystemFromURL(parent);
+    const srcPath = pathFromURL(src);
+    const dstPath = pathFromURL(parent);
     if (!(srcFS && dstFS && validName(name))) {
         fail(FileError.ENCODING_ERR);
         return;
     }
 
-    var srcWinPath = cordovaPathToNative(sanitize(srcFS.winpath + srcPath));
-    var dstWinPath = cordovaPathToNative(sanitize(dstFS.winpath + dstPath));
-    var tgtFsPath = sanitize(dstPath + '/' + name);
-    var tgtWinPath = cordovaPathToNative(sanitize(dstFS.winpath + dstPath + '/' + name));
+    const srcWinPath = cordovaPathToNative(sanitize(srcFS.winpath + srcPath));
+    const dstWinPath = cordovaPathToNative(sanitize(dstFS.winpath + dstPath));
+    const tgtFsPath = sanitize(dstPath + '/' + name);
+    const tgtWinPath = cordovaPathToNative(sanitize(dstFS.winpath + dstPath + '/' + name));
     if (srcWinPath === dstWinPath || srcWinPath === tgtWinPath) {
         fail(FileError.INVALID_MODIFICATION_ERR);
         return;
@@ -490,15 +492,15 @@ module.exports = {
     },
 
     getMetadata: function (success, fail, args) {
-        var fs = getFilesystemFromURL(args[0]);
-        var path = pathFromURL(args[0]);
+        const fs = getFilesystemFromURL(args[0]);
+        const path = pathFromURL(args[0]);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var fullPath = cordovaPathToNative(fs.winpath + path);
+        const fullPath = cordovaPathToNative(fs.winpath + path);
 
-        var getMetadataForFile = function (storageFile) {
+        const getMetadataForFile = function (storageFile) {
             storageFile.getBasicPropertiesAsync().then(
                 function (basicProperties) {
                     success(new File(storageFile.name, storageFile.path, storageFile.fileType, basicProperties.dateModified, basicProperties.size));
@@ -508,10 +510,10 @@ module.exports = {
             );
         };
 
-        var getMetadataForFolder = function (storageFolder) {
+        const getMetadataForFolder = function (storageFolder) {
             storageFolder.getBasicPropertiesAsync().then(
                 function (basicProperties) {
-                    var metadata = {
+                    const metadata = {
                         size: basicProperties.size,
                         lastModifiedDate: basicProperties.dateModified
                     };
@@ -535,8 +537,8 @@ module.exports = {
     },
 
     getParent: function (win, fail, args) { // ["fullPath"]
-        var fs = getFilesystemFromURL(args[0]);
-        var path = pathFromURL(args[0]);
+        const fs = getFilesystemFromURL(args[0]);
+        const path = pathFromURL(args[0]);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
@@ -546,11 +548,11 @@ module.exports = {
             return;
         }
 
-        var parpath = path.replace(new RegExp('/[^/]+/?$', 'g'), '');
-        var parname = path.substr(parpath.length);
-        var fullPath = cordovaPathToNative(fs.winpath + parpath);
+        const parpath = path.replace(new RegExp('/[^/]+/?$', 'g'), '');
+        const parname = path.substr(parpath.length);
+        const fullPath = cordovaPathToNative(fs.winpath + parpath);
 
-        var result = new DirectoryEntry(parname, parpath, fs.name, fs.makeNativeURL(parpath));
+        const result = new DirectoryEntry(parname, parpath, fs.name, fs.makeNativeURL(parpath));
         getFolderFromPathAsync(fullPath).done(
             function () { win(result); },
             function () { fail(FileError.INVALID_STATE_ERR); }
@@ -558,20 +560,20 @@ module.exports = {
     },
 
     readAsText: function (win, fail, args) {
-        var url = args[0];
-        var enc = args[1];
-        var startPos = args[2];
-        var endPos = args[3];
+        const url = args[0];
+        const enc = args[1];
+        let startPos = args[2];
+        let endPos = args[3];
 
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var wpath = cordovaPathToNative(sanitize(fs.winpath + path));
+        const wpath = cordovaPathToNative(sanitize(fs.winpath + path));
 
-        var encoding = Windows.Storage.Streams.UnicodeEncoding.utf8;
+        let encoding = Windows.Storage.Streams.UnicodeEncoding.utf8;
         if (enc === 'Utf16LE' || enc === 'utf16LE') {
             encoding = Windows.Storage.Streams.UnicodeEncoding.utf16LE;
         } else if (enc === 'Utf16BE' || enc === 'utf16BE') {
@@ -585,8 +587,8 @@ module.exports = {
             endPos = (endPos < 0) ? Math.max(endPos + stream.size, 0) : Math.min(stream.size, endPos);
             stream.seek(startPos);
 
-            var readSize = endPos - startPos;
-            var buffer = new Windows.Storage.Streams.Buffer(readSize);
+            const readSize = endPos - startPos;
+            const buffer = new Windows.Storage.Streams.Buffer(readSize);
 
             return stream.readAsync(buffer, readSize, Windows.Storage.Streams.InputStreamOptions.none);
         }).done(function (buffer) {
@@ -601,32 +603,32 @@ module.exports = {
     },
 
     readAsBinaryString: function (win, fail, args) {
-        var url = args[0];
-        var startPos = args[1];
-        var endPos = args[2];
+        const url = args[0];
+        const startPos = args[1];
+        const endPos = args[2];
 
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var wpath = cordovaPathToNative(sanitize(fs.winpath + path));
+        const wpath = cordovaPathToNative(sanitize(fs.winpath + path));
 
         getFileFromPathAsync(wpath).then(
             function (storageFile) {
                 Windows.Storage.FileIO.readBufferAsync(storageFile).done(
                     function (buffer) {
-                        var dataReader = Windows.Storage.Streams.DataReader.fromBuffer(buffer);
+                        const dataReader = Windows.Storage.Streams.DataReader.fromBuffer(buffer);
                         // var fileContent = dataReader.readString(buffer.length);
-                        var byteArray = new Uint8Array(buffer.length);
-                        var byteString = '';
+                        const byteArray = new Uint8Array(buffer.length);
+                        let byteString = '';
                         dataReader.readBytes(byteArray);
                         dataReader.close();
-                        for (var i = 0; i < byteArray.length; i++) {
-                            var charByte = byteArray[i];
+                        for (let i = 0; i < byteArray.length; i++) {
+                            const charByte = byteArray[i];
                             // var charRepresentation = charByte <= 127 ? String.fromCharCode(charByte) : charByte.toString(16);
-                            var charRepresentation = String.fromCharCode(charByte);
+                            const charRepresentation = String.fromCharCode(charByte);
                             byteString += charRepresentation;
                         }
                         win(byteString.slice(startPos, endPos));
@@ -639,27 +641,27 @@ module.exports = {
     },
 
     readAsArrayBuffer: function (win, fail, args) {
-        var url = args[0];
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const url = args[0];
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var wpath = cordovaPathToNative(sanitize(fs.winpath + path));
+        const wpath = cordovaPathToNative(sanitize(fs.winpath + path));
 
         getFileFromPathAsync(wpath).then(
             function (storageFile) {
-                var blob = MSApp.createFileFromStorageFile(storageFile);
-                var url = URL.createObjectURL(blob, { oneTimeOnly: true }); // eslint-disable-line no-undef
-                var xhr = new XMLHttpRequest(); // eslint-disable-line no-undef
+                const blob = MSApp.createFileFromStorageFile(storageFile);
+                const url = URL.createObjectURL(blob, { oneTimeOnly: true }); // eslint-disable-line no-undef
+                const xhr = new XMLHttpRequest(); // eslint-disable-line no-undef
                 xhr.open('GET', url, true);
                 xhr.responseType = 'arraybuffer';
                 xhr.onload = function () {
-                    var resultArrayBuffer = xhr.response;
+                    let resultArrayBuffer = xhr.response;
                     // get start and end position of bytes in buffer to be returned
-                    var startPos = args[1] || 0;
-                    var endPos = args[2] || resultArrayBuffer.length;
+                    const startPos = args[1] || 0;
+                    const endPos = args[2] || resultArrayBuffer.length;
                     // if any of them is specified, we'll slice output array
                     if (startPos !== 0 || endPos !== resultArrayBuffer.length) {
                         // slice method supported only on Windows 8.1, so we need to check if it's available
@@ -668,11 +670,11 @@ module.exports = {
                             resultArrayBuffer = resultArrayBuffer.slice(startPos, endPos);
                         } else {
                             // if slice isn't available, we'll use workaround method
-                            var tempArray = new Uint8Array(resultArrayBuffer);
-                            var resBuffer = new ArrayBuffer(endPos - startPos);
-                            var resArray = new Uint8Array(resBuffer);
+                            const tempArray = new Uint8Array(resultArrayBuffer);
+                            const resBuffer = new ArrayBuffer(endPos - startPos);
+                            const resArray = new Uint8Array(resBuffer);
 
-                            for (var i = 0; i < resArray.length; i++) {
+                            for (let i = 0; i < resArray.length; i++) {
                                 resArray[i] = tempArray[i + startPos];
                             }
                             resultArrayBuffer = resBuffer;
@@ -688,26 +690,26 @@ module.exports = {
     },
 
     readAsDataURL: function (win, fail, args) {
-        var url = args[0];
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const url = args[0];
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var wpath = cordovaPathToNative(sanitize(fs.winpath + path));
+        const wpath = cordovaPathToNative(sanitize(fs.winpath + path));
 
         getFileFromPathAsync(wpath).then(
             function (storageFile) {
                 Windows.Storage.FileIO.readBufferAsync(storageFile).done(
                     function (buffer) {
-                        var strBase64 = Windows.Security.Cryptography.CryptographicBuffer.encodeToBase64String(buffer);
+                        let strBase64 = Windows.Security.Cryptography.CryptographicBuffer.encodeToBase64String(buffer);
                         // the method encodeToBase64String will add "77u/" as a prefix, so we should remove it
                         if (String(strBase64).substr(0, 4) === '77u/') {
                             strBase64 = strBase64.substr(4);
                         }
-                        var mediaType = storageFile.contentType;
-                        var result = 'data:' + mediaType + ';base64,' + strBase64;
+                        const mediaType = storageFile.contentType;
+                        const result = 'data:' + mediaType + ';base64,' + strBase64;
                         win(result);
                     }
                 );
@@ -718,24 +720,24 @@ module.exports = {
     },
 
     getDirectory: function (win, fail, args) {
-        var dirurl = args[0];
-        var path = args[1];
-        var options = args[2];
+        const dirurl = args[0];
+        const path = args[1];
+        const options = args[2];
 
-        var fs = getFilesystemFromURL(dirurl);
-        var dirpath = pathFromURL(dirurl);
+        const fs = getFilesystemFromURL(dirurl);
+        const dirpath = pathFromURL(dirurl);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var fspath = sanitize(dirpath + '/' + path);
-        var completePath = sanitize(fs.winpath + fspath);
+        const fspath = sanitize(dirpath + '/' + path);
+        const completePath = sanitize(fs.winpath + fspath);
 
-        var name = completePath.substring(completePath.lastIndexOf('/') + 1);
+        const name = completePath.substring(completePath.lastIndexOf('/') + 1);
 
-        var wpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
+        const wpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
 
-        var flag = '';
+        let flag = '';
         if (options) {
             flag = new Flags(options.create, options.exclusive);
         } else {
@@ -748,7 +750,7 @@ module.exports = {
                     storageFolder.createFolderAsync(name, Windows.Storage.CreationCollisionOption.failIfExists).done(
                         function (storageFolder) {
                             win(new DirectoryEntry(storageFolder.name, fspath, fs.name, fs.makeNativeURL(fspath)));
-                        }, function (err) { // eslint-disable-line handle-callback-err
+                        }, function (err) { // eslint-disable-line n/handle-callback-err
                             fail(FileError.PATH_EXISTS_ERR);
                         }
                     );
@@ -784,8 +786,8 @@ module.exports = {
     },
 
     remove: function (win, fail, args) {
-        var fs = getFilesystemFromURL(args[0]);
-        var path = pathFromURL(args[0]);
+        const fs = getFilesystemFromURL(args[0]);
+        const path = pathFromURL(args[0]);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
@@ -796,7 +798,7 @@ module.exports = {
             fail(FileError.NO_MODIFICATION_ALLOWED_ERR);
             return;
         }
-        var fullPath = cordovaPathToNative(fs.winpath + path);
+        const fullPath = cordovaPathToNative(fs.winpath + path);
 
         getFileFromPathAsync(fullPath).then(
             function (storageFile) {
@@ -843,8 +845,8 @@ module.exports = {
     },
 
     removeRecursively: function (successCallback, fail, args) {
-        var fs = getFilesystemFromURL(args[0]);
-        var path = pathFromURL(args[0]);
+        const fs = getFilesystemFromURL(args[0]);
+        const path = pathFromURL(args[0]);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
@@ -855,7 +857,7 @@ module.exports = {
             fail(FileError.NO_MODIFICATION_ALLOWED_ERR);
             return;
         }
-        var fullPath = cordovaPathToNative(fs.winpath + path);
+        const fullPath = cordovaPathToNative(fs.winpath + path);
 
         getFolderFromPathAsync(fullPath).done(function (storageFolder) {
             storageFolder.deleteAsync().done(function (res) {
@@ -869,24 +871,24 @@ module.exports = {
     },
 
     getFile: function (win, fail, args) {
-        var dirurl = args[0];
-        var path = args[1];
-        var options = args[2];
+        const dirurl = args[0];
+        const path = args[1];
+        const options = args[2];
 
-        var fs = getFilesystemFromURL(dirurl);
-        var dirpath = pathFromURL(dirurl);
+        const fs = getFilesystemFromURL(dirurl);
+        const dirpath = pathFromURL(dirurl);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var fspath = sanitize(dirpath + '/' + path);
-        var completePath = sanitize(fs.winpath + fspath);
+        const fspath = sanitize(dirpath + '/' + path);
+        const completePath = sanitize(fs.winpath + fspath);
 
-        var fileName = completePath.substring(completePath.lastIndexOf('/') + 1);
+        const fileName = completePath.substring(completePath.lastIndexOf('/') + 1);
 
-        var wpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
+        const wpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
 
-        var flag = '';
+        let flag = '';
         if (options !== null) {
             flag = new Flags(options.create, options.exclusive);
         } else {
@@ -938,23 +940,23 @@ module.exports = {
     },
 
     readEntries: function (win, fail, args) { // ["fullPath"]
-        var fs = getFilesystemFromURL(args[0]);
-        var path = pathFromURL(args[0]);
+        const fs = getFilesystemFromURL(args[0]);
+        const path = pathFromURL(args[0]);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var fullPath = cordovaPathToNative(fs.winpath + path);
+        const fullPath = cordovaPathToNative(fs.winpath + path);
 
-        var result = [];
+        const result = [];
 
         getFolderFromPathAsync(fullPath).done(function (storageFolder) {
-            var promiseArr = [];
-            var index = 0;
+            const promiseArr = [];
+            let index = 0;
             promiseArr[index++] = storageFolder.getFilesAsync().then(function (fileList) {
                 if (fileList !== null) {
-                    for (var i = 0; i < fileList.length; i++) {
-                        var fspath = getFsPathForWinPath(fs, fileList[i].path);
+                    for (let i = 0; i < fileList.length; i++) {
+                        const fspath = getFsPathForWinPath(fs, fileList[i].path);
                         if (!fspath) {
                             fail(FileError.NOT_FOUND_ERR);
                             return;
@@ -965,8 +967,8 @@ module.exports = {
             });
             promiseArr[index++] = storageFolder.getFoldersAsync().then(function (folderList) {
                 if (folderList !== null) {
-                    for (var j = 0; j < folderList.length; j++) {
-                        var fspath = getFsPathForWinPath(fs, folderList[j].path);
+                    for (let j = 0; j < folderList.length; j++) {
+                        const fspath = getFsPathForWinPath(fs, folderList[j].path);
                         if (!fspath) {
                             fail(FileError.NOT_FOUND_ERR);
                             return;
@@ -982,21 +984,21 @@ module.exports = {
     },
 
     write: function (win, fail, args) {
-        var url = args[0];
-        var data = args[1];
-        var position = args[2];
-        var isBinary = args[3];
+        const url = args[0];
+        const data = args[1];
+        const position = args[2];
+        const isBinary = args[3];
 
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var completePath = sanitize(fs.winpath + path);
-        var fileName = completePath.substring(completePath.lastIndexOf('/') + 1);
-        var dirpath = completePath.substring(0, completePath.lastIndexOf('/'));
-        var wpath = cordovaPathToNative(dirpath);
+        const completePath = sanitize(fs.winpath + path);
+        const fileName = completePath.substring(completePath.lastIndexOf('/') + 1);
+        const dirpath = completePath.substring(0, completePath.lastIndexOf('/'));
+        const wpath = cordovaPathToNative(dirpath);
 
         function getWriteMethodForData (data, isBinary) {
             if (data instanceof Blob) {
@@ -1018,7 +1020,7 @@ module.exports = {
             throw new Error('Unsupported data type for write method');
         }
 
-        var writePromise = getWriteMethodForData(data, isBinary);
+        const writePromise = getWriteMethodForData(data, isBinary);
 
         getFolderFromPathAsync(wpath).done(
             function (storageFolder) {
@@ -1026,7 +1028,7 @@ module.exports = {
                     function (storageFile) {
                         writePromise(storageFile, data, position).done(
                             function (bytesWritten) {
-                                var written = bytesWritten || data.length;
+                                const written = bytesWritten || data.length;
                                 win(written);
                             },
                             function () {
@@ -1046,22 +1048,22 @@ module.exports = {
     },
 
     truncate: function (win, fail, args) { // ["fileName","size"]
-        var url = args[0];
-        var size = args[1];
+        const url = args[0];
+        const size = args[1];
 
-        var fs = getFilesystemFromURL(url);
-        var path = pathFromURL(url);
+        const fs = getFilesystemFromURL(url);
+        const path = pathFromURL(url);
         if (!fs) {
             fail(FileError.ENCODING_ERR);
             return;
         }
-        var completePath = sanitize(fs.winpath + path);
-        var wpath = cordovaPathToNative(completePath);
-        var dirwpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
+        const completePath = sanitize(fs.winpath + path);
+        const wpath = cordovaPathToNative(completePath);
+        const dirwpath = cordovaPathToNative(completePath.substring(0, completePath.lastIndexOf('/')));
 
         getFileFromPathAsync(wpath).done(function (storageFile) {
             // the current length of the file.
-            var leng = 0;
+            let leng = 0;
 
             storageFile.getBasicPropertiesAsync().then(function (basicProperties) {
                 leng = basicProperties.size;
@@ -1072,7 +1074,7 @@ module.exports = {
                 if (Number(size) >= 0) {
                     Windows.Storage.FileIO.readTextAsync(storageFile, Windows.Storage.Streams.UnicodeEncoding.utf8).then(function (fileContent) {
                         fileContent = fileContent.substr(0, size);
-                        var name = storageFile.name;
+                        const name = storageFile.name;
                         storageFile.deleteAsync().then(function () {
                             return getFolderFromPathAsync(dirwpath);
                         }).done(function (storageFolder) {
@@ -1122,15 +1124,15 @@ module.exports = {
     persistentFileSystem: null,
 
     requestFileSystem: function (win, fail, args) {
-        var type = args[0];
-        var size = args[1];
-        var MAX_SIZE = 10000000000;
+        const type = args[0];
+        const size = args[1];
+        const MAX_SIZE = 10000000000;
         if (size > MAX_SIZE) {
             fail(FileError.QUOTA_EXCEEDED_ERR);
             return;
         }
 
-        var fs;
+        let fs;
         switch (type) {
         case LocalFileSystem.TEMPORARY:
             fs = getFS('temporary');
@@ -1143,16 +1145,16 @@ module.exports = {
     },
 
     resolveLocalFileSystemURI: function (success, fail, args) {
-        var uri = args[0];
+        const uri = args[0];
 
-        var path = pathFromURL(uri);
-        var fs = getFilesystemFromURL(uri);
+        let path = pathFromURL(uri);
+        const fs = getFilesystemFromURL(uri);
         if (!fs || !validName(path)) {
             fail(FileError.ENCODING_ERR);
             return;
         }
         if (path.indexOf(fs.winpath) === 0) { path = path.substr(fs.winpath.length); }
-        var abspath = cordovaPathToNative(fs.winpath + path);
+        const abspath = cordovaPathToNative(fs.winpath + path);
 
         getFileFromPathAsync(abspath).done(
             function (storageFile) {
